.partition: Partition the test set based on a trained tree
Description
Partition the test set based on a trained tree
Usage
.partition(x1, x2, x3, x4, x5, x6)
Arguments
- x1
the tree component of the REmrt object
- x2
the moderators in the test set
- x3
indicates whether a moderator is numeric or not
- x4
the index vector of the spliting moderators
- x5
the list of split points
- x6
the moderators in the training set