A function to draw the confidence interval as a diamond
CI_draw(plotobj, x, y, a = 1, b = 1)a ggplot object
the obj to be plot
the x coordinate of the center to be plotted
the y coordinate of the center to be plotted
the distance between the center to the vertext on x-axis of the diamond
the distance between the center to the vertext on x-axis of the diamond