Learn R Programming

metacart (version 3.0.4)

Q_selected_size_GS: A function returns the Q-between from the tree with given size

Description

A function returns the Q-between from the tree with given size

Usage

Q_selected_size_GS(tree, nsplit, mods, minbucket, minsplit, ...)

Value

The pruned tree

Arguments

tree

A initial tree fitted by rpart, needs to an rpart object.

nsplit

the required number of splits

mods

the moderators found by the tree.

minbucket

the minimum number of observations in any terminal <leaf> node.

minsplit

the minimum number of observations that must exist in a node in order for a split to be attempted.

...

Additional arguments passed to prune.rpart().