Learn R Programming

metacart (version 3.0.4)

REmrt_GS_: A function to fit the tree with look-ahead option

Description

A function to fit the tree with look-ahead option

Usage

REmrt_GS_(mf, maxL, minbucket, minsplit, cp, lookahead)

Value

a list including a tree, the split points, the data, and the nodes after each split

Arguments

mf

the data.frame to grow the tree

maxL

the maximum number of splits

minbucket

the minimum number of the studies in a terminal node

minsplit

the minimal number of studies in a parent node to be split

cp

the stopping rule for decrease of between-subgroups Q. Any split that does not decrease the between-subgroups Q is not attempted.

lookahead

an argument indicating whether to apply the "look-ahead" strategy when fitting the tree