A function to fit the tree with look-ahead option
REmrt_SSS(
mf,
maxL,
minbucket,
minsplit,
cp,
lookahead,
alpha.endcut = 0.02,
a = 50,
multi.start = T,
n.starts = 3
)a list including a tree, the split points, the data, and the nodes after each split
the data.frame to grow the tree
the maximum number of splits
the minimum number of the studies in a terminal node
the minimal number of studies in a parent node to be split
the stopping rule for decrease of between-subgroups Q. Any split that does not decrease the between-subgroups Q is not attempted.
an argument indicating whether to apply the "look-ahead" strategy when fitting the tree
parameter used in the splitting algorithm to avoid the endcut preference problem.
parameter used in the sss to determine the slope of the logistic function that replaces the indicator function.
boolean indicating whether multiple starts must be used
number of multiple starts