Learn R Programming

metacart (version 3.0.4)

find_triplet: A function to find the best triplets of parent, moderator, and split point.

Description

A function to find the best triplets of parent, moderator, and split point.

Usage

find_triplet(xk, nodeMbrship, y, vi, minbucket, minsplit)

Value

pleaf the parent node

cstar the split point

rank the rank used to order a categorical moderator

Arguments

xk

moderator vector

nodeMbrship

node membership vector

y

effect size

vi

sampling variance

minbucket

the minimal number of studies in child nodes

minsplit

the minimal number of studies in parent node