A function returns the Q-between from the tree with given size
permuteFE(
mf,
Call,
nsplit,
P = 100,
sss,
lookahead,
minbucket = 3,
minsplit = 6,
cp = 1e-04,
maxdepth = 10,
alpha.endcut = 0.02,
a = 50,
multi.start = T,
n.starts = 3,
...
)The pruned tree
data transformed to fit the tree.
The matched call.
the required number of splits.
the number of permuted data sets.
boolean indicating whether the SSS strategy is used or not.
a boolean argument indicating whether to apply the "look-ahead" strategy when fitting the tree
the minimum number of observations in any terminal <leaf> node.
the minimum number of observations that must exist in a node in order for a split to be attempted.
complexity parameter as in rpart.
set the maximum depth of any node of the final tree, with the root node counted as depth 0.
parameter used in the splitting algorithm to avoid the endcut preference problem.
parameter used in the sss to determine the slope of the logistic function that replaces the indicator function.
boolean indicating whether multiple starts must be used
number of multiple starts
Additional arguments passed to prune.rpart().