Learn R Programming

metacart (version 3.0.4)

treepruner: Prune a tree

Description

Prune an initial rpart tree by "c-standard-error" rule.

Usage

treepruner(tree, c, ...)

Value

The pruned tree

Arguments

tree

A initial tree fitted by rpart, needs to an rpart object.

c

A scalar to prune the tree by selecting the tree with minum cross-validation error plus the standard error multiplied by c.

...

Additional arguments passed to prune.rpart().