A function returns the Q-between from the tree with given size
Q_selected_size_GS(tree, nsplit, mods, minbucket, minsplit, ...)The pruned tree
A initial tree fitted by rpart, needs to an rpart object.
the required number of splits
the moderators found by the tree.
the minimum number of observations in any terminal <leaf> node.
the minimum number of observations that must exist in a node in order for a split to be attempted.
Additional arguments passed to prune.rpart().