A function to find the best triplets of parent, moderator, and split point.
find_triplet(xk, nodeMbrship, y, vi, minbucket, minsplit)pleaf the parent node
cstar the split point
rank the rank used to order a categorical moderator
moderator vector
node membership vector
effect size
sampling variance
the minimal number of studies in child nodes
the minimal number of studies in parent node